//+------------------------------------------------------------------+
//|                                                     gradient.mq5 |
//|                              Copyright  2015, Vladimir Karputov |
//|                                           http://wmua.ru/slesar/ |
//+------------------------------------------------------------------+
#property copyright "Copyright  2015, Vladimir Karputov"
#property link      "http://wmua.ru/slesar/"
#property version   "1.00"
#property description "The script draws a gradient fill"
//--- show the window of input parameters when launching the script
#property script_show_inputs
#include <Canvas\Canvas.mqh>
//---
int            Width=-1;
int            Height=-1;
//--- inputs
input color clr_start=clrRed;
input color clr_end=clrBlue;
input uchar alpha=200;             //alpha channel managing color transparency
//+------------------------------------------------------------------+
//| Script program start function                                    |
//+------------------------------------------------------------------+
int OnStart()
  {
//---
   int chrt_width=ChartWidthInPixels();
   int chrt_height=ChartHeightInPixelsGet();
   Width=chrt_width*2/3;
   Height=chrt_height*2/3;
//--- create canvas
   ResetLastError();
   CCanvas canvas_;
   if(!canvas_.CreateBitmapLabel("canvas_",(chrt_width-Width)/2,(chrt_height-Height)/2,Width,Height,COLOR_FORMAT_ARGB_NORMALIZE))
     {
      Print("Error creating canvas: ",GetLastError());
      return(-1);
     }
   canvas_.Erase(ColorToARGB(clrNONE,0));
   canvas_.Update();
//--- horizontal gradient
   int i,h;
   uchar a,r,g,b;
   uint s,e;
   double transformation;
   h=Width;
   s=ColorToARGB(clr_start,alpha);
   e=ColorToARGB(clr_end,alpha);
   a=(uchar)GETRGBA(s);
   for(i=0;i<h;i++)
     {
      transformation=(double)i/h;
      r=(uchar)(GETRGBR(s)-(GETRGBR(s)-MathCeil(GETRGBR(e)))*transformation);
      g=(uchar)(GETRGBG(s)-(GETRGBG(s)-MathCeil(GETRGBG(e)))*transformation);
      b=(uchar)(GETRGBB(s)-(GETRGBB(s)-MathCeil(GETRGBB(e)))*transformation);
      canvas_.LineVertical(i,0,Height,ARGB(a,r,g,b));
      canvas_.Update();
      Sleep(5);
     }
   canvas_.Update();
   Sleep(3000);
//--- finish
   ObjectDelete(0,"canvas_");
   canvas_.Destroy();
   return(0);
  }
//+------------------------------------------------------------------+
//| Gets the width of chart (in pixels)                              |
//+------------------------------------------------------------------+
int ChartWidthInPixels(const long chart_ID=0)
  {
//--- prepare the variable to get the property value
   long result=-1;
//--- reset the error value
   ResetLastError();
//--- receive the property value
   if(!ChartGetInteger(chart_ID,CHART_WIDTH_IN_PIXELS,0,result))
     {
      //--- display the error message in Experts journal
      Print(__FUNCTION__+", Error Code = ",GetLastError());
     }
//--- return the value of the chart property
   return((int)result);
  }
//+------------------------------------------------------------------+
//| Gets the height of chart (in pixels)                             |
//+------------------------------------------------------------------+
int ChartHeightInPixelsGet(const long chart_ID=0,const int sub_window=0)
  {
//--- prepare the variable to get the property value
   long result=-1;
//--- reset the error value
   ResetLastError();
//--- receive the property value
   if(!ChartGetInteger(chart_ID,CHART_HEIGHT_IN_PIXELS,sub_window,result))
     {
      //--- display the error message in Experts journal
      Print(__FUNCTION__+", Error Code = ",GetLastError());
     }
//--- return the value of the chart property
   return((int)result);
  }
//+------------------------------------------------------------------+
//| Horizontal Gradient                                              |
//+------------------------------------------------------------------+
uchar GradientHorizontal()
  {
   return(0);
  }
//+------------------------------------------------------------------+
